@@ -116,22 +116,6 @@ public:
          */
         virtual bool authenticate(int id, const char *realm);
 
-        /**
-         * To be used to allow a plugin to redirect a target to a user.  I do
-         * not beleive this is presently used.
-         * @param target destination being dialed.
-         * @return user registration to use, or NULL to ignore.
-         */
-        virtual MappedRegistry *redirect(const char *target);
-
-        /**
-         * To allow plugins to map inbound requests to a user.  I do not
-         * believe this is presently used.
-         * @param request_uri.
-         * @return user registration of request, or NULL to ignore.
-         */
-        virtual MappedRegistry *accept(const char *request_uri);
-
         /**
          * Enables plugin to redirect locally dialed destination to new uri.
          * Might be used by a plugin that does per-user speed-dialing
